from database import app

from flask_covid19 import ApplicationServiceConfig
from flask_covid19 import ApplicationServiceDownload
from flask_covid19 import DiviServiceImport
from flask_covid19 import DiviServiceUpdate, DiviServiceUpdateFull


class DiviService:
    def __init__(self, database):
        app.logger.debug("------------------------------------------------------------")
        app.logger.debug(" DIVI Service [init]")
        app.logger.debug("------------------------------------------------------------")
        self.__database = database
        self.cfg = ApplicationServiceConfig.create_config_for_intensivregister()
        self.service_download = ApplicationServiceDownload(database, self.cfg)
        self.service_import = DiviServiceImport(database, self.cfg)
        self.service_update = DiviServiceUpdate(database, self.cfg)
        self.service_update_full = DiviServiceUpdateFull(database, self.cfg)
        app.logger.debug("------------------------------------------------------------")
        app.logger.info(" DIVI Service [ready]")

    def download(self):
        self.service_download.download_file()
        return self

    def import_file(self):
        self.service_import.import_file()
        return self

    def full_update_dimension_tables(self):
        self.service_update_full.full_update_dimension_tables()
        return self

    def update_dimension_tables(self):
        self.service_update.update_dimension_tables()
        return self

    def full_update_fact_table(self):
        self.service_update_full.full_update_fact_table()
        return self

    def update_fact_table(self):
        self.service_update.update_fact_table()
        return self

    def full_update_star_schema(self):
        self.service_import.import_file()
        self.service_update_full.full_update_star_schema()
        return self

    def update_star_schema(self):
        self.service_import.import_file()
        self.service_update.update_star_schema()
        return self
