from flask import flash

from database import app
from flask_covid19 import ApplicationServiceConfig
from flask_covid19 import ApplicationServiceDownload
from flask_covid19 import RkiVaccinationServiceImport
from flask_covid19 import RkiVaccinationServiceUpdate, RkiVaccinationServiceUpdateFull


class RkiVaccinationService:
    def __init__(self, database):
        app.logger.debug("------------------------------------------------------------")
        app.logger.debug(" Vaccination Service [init]")
        app.logger.debug("------------------------------------------------------------")
        self.__database = database
        self.cfg = ApplicationServiceConfig.create_config_for_rki_vaccination()
        self.service_download = ApplicationServiceDownload(database, self.cfg)
        self.service_import = RkiVaccinationServiceImport(database, self.cfg)
        self.service_update = RkiVaccinationServiceUpdate(database, self.cfg)
        self.service_update_full = RkiVaccinationServiceUpdateFull(database, self.cfg)
        app.logger.debug("------------------------------------------------------------")
        app.logger.info(" Vaccination Service [ready]")

    def download(self):
        self.service_download.download_file()
        return self

    def import_file(self):
        self.service_import.import_file()
        return self

    def full_update_dimension_tables(self):
        self.service_update_full.update_dimension_tables_only()
        return self

    def update_dimension_tables(self):
        self.service_update.update_dimension_tables_only()
        return self

    def full_update_fact_table(self):
        self.service_update_full.update_fact_table_initial_only()
        return self

    def update_fact_table(self):
        self.service_update.update_fact_table_incremental_only()
        return self

    def full_update_star_schema(self):
        self.import_file()
        self.service_update_full.update_star_schema_initial()
        return self

    def update_star_schema(self):
        self.service_update.update_star_schema_incremental()
        return self

