from flask import flash

from database import app
from flask_covid19 import ApplicationServiceConfig
from flask_covid19 import ApplicationServiceDownload
from flask_covid19 import WhoServiceImport
from flask_covid19 import WhoServiceUpdate, WhoServiceUpdateFull


class WhoService:
    def __init__(self, database):
        app.logger.debug("------------------------------------------------------------")
        app.logger.debug(" WHO Service [init]")
        app.logger.debug("------------------------------------------------------------")
        self.__database = database
        self.cfg = ApplicationServiceConfig.create_config_for_who()
        self.service_download = ApplicationServiceDownload(database, self.cfg)
        self.service_import = WhoServiceImport(database, self.cfg)
        self.service_update = WhoServiceUpdate(database, self.cfg)
        self.service_update_full = WhoServiceUpdateFull(database, self.cfg)
        app.logger.debug("------------------------------------------------------------")
        app.logger.info(" WHO Service [ready]")

    def database_drop_create_pretask(self):
        flash("WhoService.database_drop_create_pretask [start]")
        app.logger.info("WhoService.pretask_database_drop_create [start]")
        self.service_download.download_file()
        app.logger.info("WhoService.pretask_database_drop_create [done]")
        flash("WhoService.database_drop_create_pretask [done]")
        return self

    def database_drop_create_posttask(self):
        app.logger.info("WhoService.database_drop_create_posttask [start]")
        self.service_import.import_file()
        self.service_update_full.full_update_dimension_tables()
        self.service_update_full.full_update_fact_table()
        app.logger.info("WhoService.database_drop_create_posttask [done]")
        return self

    def full_update_dimension_tables(self):
        self.service_update_full.full_update_dimension_tables()
        return self

    def update_dimension_tables(self):
        self.service_update.update_dimension_tables()
        return self

    def download(self):
        self.service_download.download_file()
        return self

    def import_file(self):
        self.service_import.import_file()
        return self

    def full_update_star_schema(self):
        self.service_import.import_file()
        self.service_update_full.full_update_star_schema()
        return self

    def update_star_schema(self):
        self.service_import.import_file()
        self.service_update.update_star_schema()
        return self

    def full_update_fact_table(self):
        self.service_import.import_file()
        self.service_update_full.full_update_fact_table()
        return self

    def update_fact_table(self):
        self.service_import.import_file()
        self.service_update.update_star_schema()
        return self




